position property
The offset of the target the tooltip is positioned near in the global coordinate system.
Implementation
final Offset position;
The offset of the target the tooltip is positioned near in the global coordinate system.
final Offset position;